# Generated by Django 4.0.4 on 2022-06-04 07:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sotp', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='usersotp',
            name='verified',
            field=models.BooleanField(default=False),
        ),
    ]
