# Generated by Django 4.0.4 on 2022-10-01 05:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sotp', '0002_usersotp_verified'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='usersotp',
            table='secured_otps',
        ),
    ]
